@@ -537,14 +537,16 @@ impl<const N: usize> Write for StaticVec<u8, { N }> {
 
 #[cfg(feature = "serde_support")]
 impl<'de, T, const N: usize> Deserialize<'de> for StaticVec<T, { N }>
-where T: Deserialize<'de> {
+where T: Deserialize<'de>
+{
   #[inline]
   fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>
   where D: Deserializer<'de> {
     struct StaticVecVisitor<'de, T, const N: usize>(PhantomData<(&'de (), T)>);
 
     impl<'de, T, const N: usize> Visitor<'de> for StaticVecVisitor<'de, T, { N }>
-    where T: Deserialize<'de> {
+    where T: Deserialize<'de>
+    {
       type Value = StaticVec<T, { N }>;
 
       #[inline(always)]
@@ -574,7 +576,8 @@ where T: Deserialize<'de> {
 
 #[cfg(feature = "serde_support")]
 impl<T, const N: usize> Serialize for StaticVec<T, { N }>
-where T: Serialize {
+where T: Serialize
+{
   #[inline(always)]
   fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error>
   where S: Serializer {
